summaryrefslogtreecommitdiffstats
path: root/kmail/kmmsgbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmmsgbase.h')
-rw-r--r--kmail/kmmsgbase.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kmail/kmmsgbase.h b/kmail/kmmsgbase.h
index 1137bb6e..d5b7107f 100644
--- a/kmail/kmmsgbase.h
+++ b/kmail/kmmsgbase.h
@@ -220,9 +220,9 @@ public:
/** Set status and mark dirty. Optional optimization: @p idx may
* specify the index of this message within the parent folder. */
- virtual void setStatus(const KMMsgStatus status, int idx = -1);
+ virtual void seStatus(const KMMsgStatus status, int idx = -1);
virtual void toggleStatus(const KMMsgStatus status, int idx = -1);
- virtual void setStatus(const char* statusField, const char* xstatusField=0);
+ virtual void seStatus(const char* statusField, const char* xstatusField=0);
/** Encryption status of the message. */
virtual KMMsgEncryptionState encryptionState() const = 0;
@@ -403,18 +403,18 @@ public:
/** Return if the message has at least one attachment */
virtual KMMsgAttachmentState attachmentState() const;
- /** Return if the message contains an invitation */
+ /** Return if the message tqcontains an invitation */
virtual KMMsgInvitationState invitationState() const;
/** Check for prefixes @p prefixRegExps in @p str. If none
is found, @p newPrefix + ' ' is prepended to @p str and the
- resulting string is returned. If @p replace is true, any
+ resulting string is returned. If @p tqreplace is true, any
sequence of whitespace-delimited prefixes at the beginning of
- @p str is replaced by @p newPrefix.
+ @p str is tqreplaced by @p newPrefix.
**/
- static TQString replacePrefixes( const TQString& str,
+ static TQString tqreplacePrefixes( const TQString& str,
const TQStringList& prefixRegExps,
- bool replace,
+ bool tqreplace,
const TQString& newPrefix );
/** Returns @p str with all "forward" and "reply" prefixes stripped off.
@@ -423,11 +423,11 @@ public:
/** Check for prefixes @p prefixRegExps in #subject(). If none
is found, @p newPrefix + ' ' is prepended to the subject and the
- resulting string is returned. If @p replace is true, any
+ resulting string is returned. If @p tqreplace is true, any
sequence of whitespace-delimited prefixes at the beginning of
#subject() is replaced by @p newPrefix
**/
- TQString cleanSubject(const TQStringList& prefixRegExps, bool replace,
+ TQString cleanSubject(const TQStringList& prefixRegExps, bool tqreplace,
const TQString& newPrefix) const;
/** Return this mails subject, with all "forward" and "reply"
@@ -459,7 +459,7 @@ public:
enum MsgPartType
{
MsgNoPart = 0,
- //unicode strings
+ //tqunicode strings
MsgFromStripPart = 1,
MsgSubjectPart = 2,
MsgToStripPart = 3,
@@ -474,7 +474,7 @@ public:
MsgFilePart = 11,
MsgCryptoStatePart = 12,
MsgMDNSentPart = 13,
- //another two unicode strings
+ //another two tqunicode strings
MsgReplyToAuxIdMD5Part = 14,
MsgStrippedSubjectMD5Part = 15,
// and another unsigned long
@@ -423,11 +423,11 @@ public:
sequence of whitespace-delimited prefixes at the beginning of
- #subject() is replaced by @p newPrefix
+ #subject() is tqreplaced by @p newPrefix
**/